==> embrace-android-sdk-4.7.0-sources.jar: io/embrace/android/embracesdk/AppInfo.java <==
package io.embrace.android.embracesdk;

import com.google.gson.annotations.SerializedName;

/**
 * Version and environment information relating to the app which has embedded the Embrace SDK.
 */
final class AppInfo {

    /**
     * The version of the app which has embedded the Embrace SDK.
     */
    @SerializedName("v")
    private final String appVersion;

    /**
     * The framework used by the app.
     */
    @SerializedName("f")
    private final Integer appFramework;

    /**
     * A unique ID for the build which is generated at build time. This is written to a JSON file in
     * the build directory and read by {@link BuildInfo}.
     */
    @SerializedName("bi")
    private final String buildId;

    /**
     * The build type name. This is written to a JSON file in the build directory and read by
     * {@link BuildInfo}.
     */
    @SerializedName("bt")
    private final String buildType;

    /**
     * The flavor name. This is written to a JSON file in the build directory and read by
     * {@link BuildInfo}.
     */
    @SerializedName("fl")
    private final String buildFlavor;

    /**
     * The name of the environment, i.e. dev or prod, determined by whether this is a debug build.
     */
    @SerializedName("e")
    private final String environment;

    /**
     * Whether the app was updated since the previous launch.
     */
    @SerializedName("vu")
    private final boolean appUpdated;

    /**
     * Whether the app was updated since the previous launch.
     */
    @SerializedName("vul")
    private final boolean appUpdatedThisLaunch;

    /**
     * The app bundle version.
     */
    @SerializedName("bv")
    private final String bundleVersion;

    /**
     * Whether the OS was updated since the last launch.
     */
    @SerializedName("ou")
    private final boolean osUpdated;

    /**
     * Whether the OS was updated since the last launch.
     */
    @SerializedName("oul")
    private final boolean osUpdatedThisLaunch;

    /**
     * The version number of the Embrace SDK.
     */
    @SerializedName("sdk")
    private final String sdkVersion;

    /**
     * The simple version number of the Embrace SDK.
     */
    @SerializedName("sdc")
    private final String sdkSimpleVersion;

    /**
     * The react native bundle hashed.
     */
    @SerializedName("rn")
    private final String reactNativeBundlePath;

    /**
     * The java script patch number.
     */
    @SerializedName("jsp")
    private final String javaScriptPatchNumber;

    /**
     * The react native version number.
     */
    @SerializedName("rnv")
    private final String reactNativeVersion;

    /**
     * The unity version number.
     */
    @SerializedName("unv")
    private final String unityVersion;

    /**
     * The unity build id number.
     */
    @SerializedName("ubg")
    private final String buildGUID;

    private AppInfo(Builder builder) {
        appFramework = builder.appFramework;
        appVersion = builder.appVersion;
        buildId = builder.buildId;
        buildType = builder.buildType;
        buildFlavor = builder.buildFlavor;
        environment = builder.environment;
        appUpdated = builder.appUpdated;
        appUpdatedThisLaunch = builder.appUpdatedThisLaunch;
        bundleVersion = builder.bundleVersion;
        osUpdated = builder.osUpdated;
        osUpdatedThisLaunch = builder.osUpdatedThisLaunch;
        sdkVersion = builder.sdkVersion;
        sdkSimpleVersion = builder.sdkSimpleVersion;
        reactNativeBundlePath = builder.reactNativeBundlePath;
        javaScriptPatchNumber = builder.javaScriptPatch;
        reactNativeVersion = builder.reactNativeVersion;
        unityVersion = builder.unityVersion;
        buildGUID = builder.buildGUID;
    }

    static Builder newBuilder() {
        return new Builder();
    }


    static final class Builder {
        private Integer appFramework;
        private String appVersion;
        private String buildId;
        private String buildType;
        private String buildFlavor;
        private String environment;
        private boolean appUpdated;
        private boolean appUpdatedThisLaunch;
        private String bundleVersion;
        private boolean osUpdated;
        private boolean osUpdatedThisLaunch;
        private String sdkVersion;
        private String sdkSimpleVersion;
        private String reactNativeBundlePath;
        private String javaScriptPatch;
        private String reactNativeVersion;
        private String unityVersion;
        private String buildGUID;

        private Builder() {
        }

        Builder withAppFramework(Embrace.AppFramework appFramework) {
            this.appFramework = appFramework.getValue();
            return this;
        }

        Builder withAppVersion(String appVersion) {
            this.appVersion = appVersion;
            return this;
        }

        Builder withBuildId(String buildId) {
            this.buildId = buildId;
            return this;
        }

        Builder withBuildType(String buildType) {
            this.buildType = buildType;
            return this;
        }

        Builder withBuildFlavor(String buildFlavor) {
            this.buildFlavor = buildFlavor;
            return this;
        }

        Builder withEnvironment(String environment) {
            this.environment = environment;
            return this;
        }

        Builder withAppUpdated(boolean appUpdated) {
            this.appUpdated = appUpdated;
            return this;
        }

        Builder withAppUpdatedThisLaunch(boolean appUpdatedThisLaunch) {
            this.appUpdatedThisLaunch = appUpdatedThisLaunch;
            return this;
        }

        Builder withBundleVersion(String bundleVersion) {
            this.bundleVersion = bundleVersion;
            return this;
        }

        Builder withOsUpdated(boolean osUpdated) {
            this.osUpdated = osUpdated;
            return this;
        }

        Builder withOsUpdatedThisLaunch(boolean osUpdatedThisLaunch) {
            this.osUpdatedThisLaunch = osUpdatedThisLaunch;
            return this;
        }

        Builder withSdkVersion(String sdkVersion) {
            this.sdkVersion = sdkVersion;
            return this;
        }

        Builder withSdkSimpleVersion(String sdkSimpleVersion) {
            this.sdkSimpleVersion = sdkSimpleVersion;
            return this;
        }

        Builder withReactNativeBundlePath(String reactNativeBundlePath) {
            this.reactNativeBundlePath = reactNativeBundlePath;
            return this;
        }

        Builder withJavaScriptPatchNumber(String number) {
            this.javaScriptPatch = number;
            return this;
        }

        Builder withReactNativeVersion(String version) {
            this.reactNativeVersion = version;
            return this;
        }

        Builder withUnityVersion(String version) {
            this.unityVersion = version;
            return this;
        }

        Builder withUnityBuildId(String buildId) {
            this.buildGUID = buildId;
            return this;
        }

        AppInfo build() {
            return new AppInfo(this);
        }
    }

    public String toJson() {
        return String.format(
                "{\"v\": %s,\"f\": %s,\"bi\":%s,\"bt\":%s,\"fl\":%s,\"e\":%s,\"vu\":%s," +
                "\"vul\":%s,\"bv\":%s,\"ou\":%s,\"oul\":%s,\"sdk\":%s,\"sdc\":%s," +
                "\"rn\":%s,\"jsp\":%s,\"rnv\":%s,\"unv\":%s,\"ubg\":%s}",
                MessageUtils.withNull(appVersion),
                appFramework,
                MessageUtils.withNull(buildId),
                MessageUtils.withNull(buildType),
                MessageUtils.withNull(buildFlavor),
                MessageUtils.withNull(environment),
                MessageUtils.boolToStr(appUpdated),
                MessageUtils.boolToStr(appUpdatedThisLaunch),
                MessageUtils.withNull(bundleVersion),
                MessageUtils.boolToStr(osUpdated),
                MessageUtils.boolToStr(osUpdatedThisLaunch),
                MessageUtils.withNull(sdkVersion),
                MessageUtils.withNull(sdkSimpleVersion),
                MessageUtils.withNull(reactNativeBundlePath),
                MessageUtils.withNull(javaScriptPatchNumber),
                MessageUtils.withNull(reactNativeVersion),
                MessageUtils.withNull(unityVersion),
                MessageUtils.withNull(buildGUID));
    }
}

==> embrace-android-sdk-5.5.2-sources.jar: io/embrace/android/embracesdk/AppInfo.java <==
package io.embrace.android.embracesdk;

import com.google.gson.annotations.SerializedName;

/**
 * Version and environment information relating to the app which has embedded the Embrace SDK.
 */
final class AppInfo {

    /**
     * The version of the app which has embedded the Embrace SDK.
     */
    @SerializedName("v")
    private final String appVersion;

    /**
     * The framework used by the app.
     */
    @SerializedName("f")
    private final Integer appFramework;

    /**
     * A unique ID for the build which is generated at build time. This is written to a JSON file in
     * the build directory and read by {@link BuildInfo}.
     */
    @SerializedName("bi")
    private final String buildId;

    /**
     * The build type name. This is written to a JSON file in the build directory and read by
     * {@link BuildInfo}.
     */
    @SerializedName("bt")
    private final String buildType;

    /**
     * The flavor name. This is written to a JSON file in the build directory and read by
     * {@link BuildInfo}.
     */
    @SerializedName("fl")
    private final String buildFlavor;

    /**
     * The name of the environment, i.e. dev or prod, determined by whether this is a debug build.
     */
    @SerializedName("e")
    private final String environment;

    /**
     * Whether the app was updated since the previous launch.
     */
    @SerializedName("vu")
    private final boolean appUpdated;

    /**
     * Whether the app was updated since the previous launch.
     */
    @SerializedName("vul")
    private final boolean appUpdatedThisLaunch;

    /**
     * The app bundle version.
     */
    @SerializedName("bv")
    private final String bundleVersion;

    /**
     * Whether the OS was updated since the last launch.
     */
    @SerializedName("ou")
    private final boolean osUpdated;

    /**
     * Whether the OS was updated since the last launch.
     */
    @SerializedName("oul")
    private final boolean osUpdatedThisLaunch;

    /**
     * The version number of the Embrace SDK.
     */
    @SerializedName("sdk")
    private final String sdkVersion;

    /**
     * The simple version number of the Embrace SDK.
     */
    @SerializedName("sdc")
    private final String sdkSimpleVersion;

    /**
     * The react native bundle hashed.
     */
    @SerializedName("rn")
    private final String reactNativeBundleID;

    /**
     * The java script patch number.
     */
    @SerializedName("jsp")
    private final String javaScriptPatchNumber;

    /**
     * The react native version number.
     */
    @SerializedName("rnv")
    private final String reactNativeVersion;

    /**
     * The unity version number.
     */
    @SerializedName("unv")
    private final String unityVersion;

    /**
     * The unity build id number.
     */
    @SerializedName("ubg")
    private final String buildGUID;

    AppInfo(Builder builder) {
        appFramework = builder.appFramework;
        appVersion = builder.appVersion;
        buildId = builder.buildId;
        buildType = builder.buildType;
        buildFlavor = builder.buildFlavor;
        environment = builder.environment;
        appUpdated = builder.appUpdated;
        appUpdatedThisLaunch = builder.appUpdatedThisLaunch;
        bundleVersion = builder.bundleVersion;
        osUpdated = builder.osUpdated;
        osUpdatedThisLaunch = builder.osUpdatedThisLaunch;
        sdkVersion = builder.sdkVersion;
        sdkSimpleVersion = builder.sdkSimpleVersion;
        reactNativeBundleID = builder.reactNativeBundleID;
        javaScriptPatchNumber = builder.javaScriptPatch;
        reactNativeVersion = builder.reactNativeVersion;
        unityVersion = builder.unityVersion;
        buildGUID = builder.buildGUID;
    }

    static Builder newBuilder() {
        return new Builder();
    }


    static final class Builder {
        Integer appFramework;
        String appVersion;
        String buildId;
        String buildType;
        String buildFlavor;
        String environment;
        boolean appUpdated;
        boolean appUpdatedThisLaunch;
        String bundleVersion;
        boolean osUpdated;
        boolean osUpdatedThisLaunch;
        String sdkVersion;
        String sdkSimpleVersion;
        String reactNativeBundleID;
        String javaScriptPatch;
        String reactNativeVersion;
        String unityVersion;
        String buildGUID;

        Builder() {
        }

        Builder withAppFramework(Embrace.AppFramework appFramework) {
            this.appFramework = appFramework.getValue();
            return this;
        }

        Builder withAppVersion(String appVersion) {
            this.appVersion = appVersion;
            return this;
        }

        Builder withBuildId(String buildId) {
            this.buildId = buildId;
            return this;
        }

        Builder withBuildType(String buildType) {
            this.buildType = buildType;
            return this;
        }

        Builder withBuildFlavor(String buildFlavor) {
            this.buildFlavor = buildFlavor;
            return this;
        }

        Builder withEnvironment(String environment) {
            this.environment = environment;
            return this;
        }

        Builder withAppUpdated(boolean appUpdated) {
            this.appUpdated = appUpdated;
            return this;
        }

        Builder withAppUpdatedThisLaunch(boolean appUpdatedThisLaunch) {
            this.appUpdatedThisLaunch = appUpdatedThisLaunch;
            return this;
        }

        Builder withBundleVersion(String bundleVersion) {
            this.bundleVersion = bundleVersion;
            return this;
        }

        Builder withOsUpdated(boolean osUpdated) {
            this.osUpdated = osUpdated;
            return this;
        }

        Builder withOsUpdatedThisLaunch(boolean osUpdatedThisLaunch) {
            this.osUpdatedThisLaunch = osUpdatedThisLaunch;
            return this;
        }

        Builder withSdkVersion(String sdkVersion) {
            this.sdkVersion = sdkVersion;
            return this;
        }

        Builder withSdkSimpleVersion(String sdkSimpleVersion) {
            this.sdkSimpleVersion = sdkSimpleVersion;
            return this;
        }

        Builder withReactNativeBundleID(String reactNativeBundleID) {
            this.reactNativeBundleID = reactNativeBundleID;
            return this;
        }

        Builder withJavaScriptPatchNumber(String number) {
            this.javaScriptPatch = number;
            return this;
        }

        Builder withReactNativeVersion(String version) {
            this.reactNativeVersion = version;
            return this;
        }

        Builder withUnityVersion(String version) {
            this.unityVersion = version;
            return this;
        }

        Builder withUnityBuildId(String buildId) {
            this.buildGUID = buildId;
            return this;
        }

        AppInfo build() {
            return new AppInfo(this);
        }
    }

    public String toJson() {
        return "{\"v\": " + MessageUtils.withNull(appVersion) +
                ",\"f\": " + appFramework +
                ",\"bi\":" + MessageUtils.withNull(buildId) +
                ",\"bt\":" + MessageUtils.withNull(buildType) +
                ",\"fl\":" + MessageUtils.withNull(buildFlavor) +
                ",\"e\":" + MessageUtils.withNull(environment) +
                ",\"vu\":" + MessageUtils.boolToStr(appUpdated) +
                ",\"vul\":" + MessageUtils.boolToStr(appUpdatedThisLaunch) +
                ",\"bv\":" + MessageUtils.withNull(bundleVersion) +
                ",\"ou\":" + MessageUtils.boolToStr(osUpdated) +
                ",\"oul\":" + MessageUtils.boolToStr(osUpdatedThisLaunch) +
                ",\"sdk\":" + MessageUtils.withNull(sdkVersion) +
                ",\"sdc\":" + MessageUtils.withNull(sdkSimpleVersion) +
                ",\"rn\":" + MessageUtils.withNull(reactNativeBundleID) +
                ",\"jsp\":" + MessageUtils.withNull(javaScriptPatchNumber) +
                ",\"rnv\":" + MessageUtils.withNull(reactNativeVersion) +
                ",\"unv\":" + MessageUtils.withNull(unityVersion) +
                ",\"ubg\":" + MessageUtils.withNull(buildGUID) + "}";
    }
}
